/*------------------------------------------------------------
 * Example radio "receive" application
 *   Always blinks green LED.
 *   Toggles red LED every time a packet is received.
 *----------------------------------------------------------*/

#include "bsp.h"
#include "mrfi.h"
#include "radios/family1/mrfi_spi.h"
#include "charlie.h"
#include "msp430x22x4.h"

/* Useful #defines */
#define RED_RECEIVE_LED 0x01
#define GREEN_LED   0x02
int LED_state[72]= {0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0,
					0, 0, 0, 0, 0, 0, 0, 0};
/* Function prototypes */
void sleep(unsigned int count);

/* Main function for receive application */
void main(void) {
	/* Set a filter address for packets received by the radio
	 *   This should match the "destination" address of
	 *   the packets sent by the transmitter. */
	uint8_t address[] = {0x12,0x34,0xab,0xcd};
	
	int i;
	/* Filter setup return value: success or failure */
	unsigned char status;
	
	/* Perform board-specific initialization */
	BSP_Init();
	
	/* Initialize minimal RF interface, wake up radio */
	MRFI_Init();
	MRFI_WakeUp();
			
	/* Attempt to turn on address filtering
	 *   If unsuccessful, turn on both LEDs and wait forever */
	status = MRFI_SetRxAddrFilter(address);	
	MRFI_EnableRxAddrFilter();
	if( status != 0) {
		P1OUT = RED_RECEIVE_LED | GREEN_LED;
		while(1);
	}
		
	/* Red and green LEDs are output, green starts on */
	P1DIR = RED_RECEIVE_LED | GREEN_LED;
	P1OUT = GREEN_LED;
	
	/* Turn on the radio receiver */
	MRFI_RxOn();
	
	/* Main loop just toggles the green LED with some delay */
	__bis_SR_register(GIE);
	while(1){
		for (i = 0 ; i <= 71; i++){
			if (LED_state[i] == 1){
				control_LED(i+1, 50);
			}
		}
	}
}


/* Function to execute upon receiving a packet
 *   Called by the driver when new packet arrives */
void MRFI_RxCompleteISR(void) {
	/* Read the received data packet */
	mrfiPacket_t	packet;
	int i;
	int j;
	MRFI_Receive(&packet);
	
    // update LED state 
	for (i = 0; i <= 8; i++) {
	 	for (j = 0; j <= 7; j ++){
	 		if (((0x01 << j) & packet.frame[9+i]) != 0){
	 			LED_state[(i*8+j)] = 1;
	 		}	
	 		else{
	 			LED_state[(i*8+j)] = 0;
	 		} 		
	 	}	
	 }
	
	
	
	/* Toggle the red LED to signal that data has arrived */
	P1OUT ^= RED_RECEIVE_LED;
}

/* Parameterized "sleep" helper function */
void sleep(unsigned int count) {
	int i;
	for (i = 0; i < 10; i++) {
		while(count > 0) {
			count--;
			__no_operation();
		}
	}
}
